@@ -30,7 +30,7 @@ import shelf
 
 from version import version_info, __version__
 from command import BzrToolsCommand
-from errors import CommandError, NoPyBaz
+from errors import CommandError
 from patchsource import BzrPatchSource
 import sys
 import os.path
@@ -44,10 +44,7 @@ from bzrlib.errors import BzrCommandError
 import bzrlib.ignores
 from bzrlib.trace import note
 from bzrlib.option import Option
-sys.path.insert(0, os.path.realpath(os.path.join(os.path.dirname(__file__),
-                                                 "external")))
 
-import show_paths
 from command import BzrToolsCommand
 
 bzrlib.ignores.add_runtime_ignores(['./.shelf'])
@@ -547,78 +544,6 @@ class cmd_cdiff(BzrToolsCommand):
         colordiff(check_style, *args, **kwargs)
 
 
-class cmd_baz_import(BzrToolsCommand):
-    """Import an Arch or Baz archive into a bzr repository.
-
-    This command should be used on local archives (or mirrors) only.  It is
-    quite slow on remote archives.
-
-    reuse_history allows you to specify any previous imports you
-    have done of different archives, which this archive has branches
-    tagged from. This will dramatically reduce the time to convert
-    the archive as it will not have to convert the history already
-    converted in that other branch.
-
-    If you specify prefixes, only branches whose names start with that prefix
-    will be imported.  Skipped branches will be listed, so you can import any
-    branches you missed by accident.  Here's an example of doing a partial
-    import from thelove@canonical.com:
-    bzr baz-import thelove thelove@canonical.com --prefixes dists:talloc-except
-
-    WARNING: Encoding should not be specified unless necessary, because if you
-    specify an encoding, your converted branch will not interoperate with
-    independently-converted branches, unless the other branches were converted
-    with exactly the same encoding.  Any encoding recognized by Python may
-    be specified.  Aliases are not detected, so 'utf_8', 'U8', 'UTF' and 'utf8'
-    are incompatible.
-    """
-    takes_args = ['to_root_dir', 'from_archive', 'reuse_history*']
-    takes_options = ['verbose', Option('prefixes', type=str,
-                     help="Prefixes of branches to import, colon-separated."),
-                     Option('encoding', type=str,
-                     help='Force encoding to specified value.  See WARNING.')]
-
-    def run(self, to_root_dir, from_archive, encoding=None, verbose=False,
-            reuse_history_list=[], prefixes=None):
-        from errors import NoPyBaz
-        try:
-            import baz_import
-            baz_import.baz_import(to_root_dir, from_archive, encoding,
-                                  verbose, reuse_history_list, prefixes)
-        except NoPyBaz:
-            print "This command is disabled.  Please install PyBaz."
-
-
-class cmd_baz_import_branch(BzrToolsCommand):
-    """Import an Arch or Baz branch into a bzr branch.
-
-    WARNING: Encoding should not be specified unless necessary, because if you
-    specify an encoding, your converted branch will not interoperate with
-    independently-converted branches, unless the other branches were converted
-    with exactly the same encoding.  Any encoding recognized by Python may
-    be specified.  Aliases are not detected, so 'utf_8', 'U8', 'UTF' and 'utf8'
-    are incompatible.
-    """
-    takes_args = ['to_location', 'from_branch?', 'reuse_history*']
-    takes_options = ['verbose', 
-                     Option('max-count', type=int, 
-                     help='Maximim revisions to import at once.'),
-                     Option('encoding', type=str,
-                     help='Force encoding to specified value.  See WARNING.')]
-
-    def run(self, to_location, from_branch=None, fast=False, max_count=None,
-            encoding=None, verbose=False, dry_run=False,
-            reuse_history_list=[]):
-        from errors import NoPyBaz
-        try:
-            import baz_import
-            baz_import.baz_import_branch(to_location, from_branch, fast,
-                                         max_count, verbose, encoding, dry_run,
-                                         reuse_history_list)
-        except NoPyBaz:
-            print "This command is disabled.  Please install PyBaz."
-
-
 class cmd_rspush(BzrToolsCommand):
     """Upload this branch to another location using rsync.
 
@@ -665,8 +590,6 @@ class cmd_link_tree(BzrToolsCommand):
 
 from heads import cmd_heads
 commands = [
-            cmd_baz_import,
-            cmd_baz_import_branch,
             cmd_branches,
             cmd_branch_history,
             cmd_cbranch,
@@ -714,11 +637,6 @@ def test_suite():
     result = TestSuite()
     result.addTest(DocTestSuite(bzrtools, optionflags=ELLIPSIS))
     result.addTest(tests.clean_tree.test_suite())
-    try:
-        import baz_import
-        result.addTest(DocTestSuite(baz_import))
-    except NoPyBaz:
-        pass
     result.addTest(tests.test_suite())
     result.addTest(TestLoader().loadTestsFromModule(tests.shelf_tests))
     result.addTest(tests.blackbox.test_suite())
