@@ -65,7 +65,7 @@ def is_clean(cur_tree):
     return not delta.has_changed(), non_source
 
 def set_push_data(tree, location):
-    tree.branch.control_files.put_utf8("x-push-data", "%s\n" % location)
+    tree.branch._transport.put_bytes("x-push-data", "%s\n" % location)
 
 def get_push_data(tree):
     """
@@ -78,10 +78,10 @@ def get_push_data(tree):
     >>> rm_tree(tree)
     """
     try:
-        location = tree.branch.control_files.get('x-push-data').read()
-        location = location.decode('utf-8')
+        location = tree.branch._transport.get('x-push-data').read()
     except NoSuchFile:
         return None
+    location = location.decode('utf-8')
     return location.rstrip('\n')
 
 """
